@@ -140,7 +140,7 @@ class ProxyListenerDynamoDB(ProxyListener):
         if response._content:
             # fix the table and latest stream ARNs (DynamoDBLocal hardcodes "ddblocal" as the region)
             content_replaced = re.sub(r'("TableArn"|"LatestStreamArn"|"StreamArn")\s*:\s*"arn:aws:dynamodb:' +
-            'ddblocal:([^"]+)"', r'\1: "arn:aws:dynamodb:%s:\2"' % aws_stack.get_local_region(),
+            'ddblocal:([^"]+)"', r'\1: "arn:aws:dynamodb:%s:\2"' % aws_stack.get_region(),
             to_str(response._content))
             if content_replaced != response._content:
                 response._content = content_replaced
@@ -157,7 +157,7 @@ class ProxyListenerDynamoDB(ProxyListener):
                 'StreamViewType': 'NEW_AND_OLD_IMAGES',
                 'SizeBytes': -1
             },
-            'awsRegion': config.DEFAULT_REGION,
+            'awsRegion': aws_stack.get_region(),
             'eventSource': 'aws:dynamodb'
         }
         records = [record]
