@@ -15,7 +15,7 @@ from six.moves.urllib import parse as urlparse
 from botocore.client import ClientError
 from requests.models import Response, Request
 from localstack import config
-from localstack.config import HOSTNAME, HOSTNAME_EXTERNAL, DEFAULT_REGION
+from localstack.config import HOSTNAME, HOSTNAME_EXTERNAL
 from localstack.utils import persistence
 from localstack.utils.aws import aws_stack
 from localstack.utils.common import (
@@ -96,7 +96,7 @@ def get_event_message(event_name, bucket_name, file_name='testfile.txt', version
         'Records': [{
             'eventVersion': '2.0',
             'eventSource': 'aws:s3',
-            'awsRegion': DEFAULT_REGION,
+            'awsRegion': aws_stack.get_region(),
             'eventTime': timestamp(format=TIMESTAMP_FORMAT_MILLIS),
             'eventName': event_name,
             'userIdentity': {
@@ -346,7 +346,7 @@ def strip_chunk_signatures(data):
     # <payload data ...>
     # 0;chunk-signature=927ab45acd82fc90a3c210ca7314d59fedc77ce0c914d79095f8cc9563cf2c70
 
-    data_new = re.sub(b'[0-9a-fA-F]+;chunk-signature=[0-9a-f]{64}(\r\n)', b'',
+    data_new = re.sub(b'(^|\r\n)[0-9a-fA-F]+;chunk-signature=[0-9a-f]{64}(\r\n)(\r\n$)?', b'',
         data, flags=re.MULTILINE | re.DOTALL)
 
     return data_new
