@@ -587,11 +587,11 @@ def is_number(s):
 
 
 def is_mac_os():
-    try:
-        out = to_str(subprocess.check_output('uname -a', shell=True))
-        return 'Darwin' in out
-    except subprocess.CalledProcessError:
-        return False
+    return bootstrap.is_mac_os()
+
+
+def is_linux():
+    return bootstrap.is_linux()
 
 
 def is_alpine():
@@ -602,14 +602,6 @@ def is_alpine():
         return False
 
 
-def is_linux():
-    try:
-        out = to_str(subprocess.check_output('uname -a', shell=True))
-        return 'Linux' in out
-    except subprocess.CalledProcessError:
-        return False
-
-
 def short_uid():
     return str(uuid.uuid4())[0:8]
 
@@ -822,12 +814,12 @@ def generate_ssl_cert(target_file=None, overwrite=False, random=False, return_co
     key_file_content = key_file.getvalue().strip()
     file_content = '%s\n%s' % (key_file_content, cert_file_content)
     if target_file:
+        key_file_name = '%s.key' % target_file
+        cert_file_name = '%s.crt' % target_file
         # check existence to avoid permission denied issues:
         # https://github.com/localstack/localstack/issues/1607
         if not os.path.exists(target_file):
             save_file(target_file, file_content)
-            key_file_name = '%s.key' % target_file
-            cert_file_name = '%s.crt' % target_file
             save_file(key_file_name, key_file_content)
             save_file(cert_file_name, cert_file_content)
             TMP_FILES.append(target_file)
